/// <reference types="@fastly/js-compute" />
/// <reference types="node" />
/// <reference types="node" />
import { PrerenderManifest } from 'next/dist/build';
import { PagesManifest } from 'next/dist/build/webpack/plugins/pages-manifest-plugin';
import { CustomRoutes } from 'next/dist/lib/load-custom-routes';
import { BaseNextRequest, BaseNextResponse } from 'next/dist/server/base-http';
import BaseServer, { FindComponentsResult, Options } from 'next/dist/server/base-server';
import { FontManifest } from 'next/dist/server/font-utils';
import { RenderOpts } from 'next/dist/server/render';
import { NextParsedUrlQuery, NextUrlWithParsedQuery } from 'next/dist/server/request-meta';
import { DynamicRoutes, PageChecker, Route } from 'next/dist/server/router';
import { PayloadOptions } from 'next/dist/server/send-payload';
import { Params } from 'next/dist/shared/lib/router/utils/route-matcher';
import { NodeNextRequest, NodeNextResponse } from 'next/dist/server/base-http/node';
import ComputeJsResponseCache from './response-cache/compute-js';
import type { IncomingMessage, ServerResponse } from 'http';
import type { ParsedUrlQuery } from 'querystring';
import type { NextConfig } from 'next';
import type RenderResult from 'next/dist/server/render-result';
import type { NodeRequestHandler } from "next/dist/server/next-server";
export interface ComputeJsServerOptions extends Options {
    computeJsConfig: {
        extendRenderOpts: Partial<BaseServer['renderOpts']>;
    };
}
export type ComputeJsRequestHandler = (request: Request) => Promise<Response>;
/**
 * An implementation of a Next.js server that has been adapted to run in Compute@Edge.
 * (An adaptation for Compute@Edge of NextNodeServer in Next.js,
 * found at next/server/next-server.ts)
 */
export default class NextComputeJsServer extends BaseServer<ComputeJsServerOptions> {
    constructor(options: ComputeJsServerOptions);
    protected loadEnvConfig(): void;
    protected getIncrementalCache(): any;
    protected getResponseCache(): ComputeJsResponseCache;
    protected getPublicDir(): string;
    protected getHasStaticDir(): boolean;
    protected getPagesManifest(): PagesManifest | undefined;
    protected getAppPathsManifest(): PagesManifest | undefined;
    protected getFilesystemPaths(): Set<string>;
    protected hasPage(pathname: string): Promise<boolean>;
    protected getBuildId(): string;
    protected getCustomRoutes(): CustomRoutes;
    protected getHasAppDir(dev: boolean): boolean;
    protected sendRenderResult(req: NodeNextRequest, res: NodeNextResponse, options: {
        result: RenderResult;
        type: "html" | "json";
        generateEtags: boolean;
        poweredByHeader: boolean;
        options?: PayloadOptions;
    }): Promise<void>;
    protected handleCompression(req: NodeNextRequest, res: NodeNextResponse): void;
    protected runApi(req: BaseNextRequest | NodeNextRequest, res: BaseNextResponse | NodeNextResponse, query: ParsedUrlQuery, params: Params | undefined, page: string, builtPagePath: string): Promise<boolean>;
    private normalizeReq;
    private normalizeRes;
    getRequestHandler(): NodeRequestHandler;
    getComputeJsRequestHandler(): ComputeJsRequestHandler;
    render(req: BaseNextRequest | IncomingMessage, res: BaseNextResponse | ServerResponse, pathname: string, query?: NextParsedUrlQuery, parsedUrl?: NextUrlWithParsedQuery, internal?: boolean): Promise<void>;
    protected renderHTML(req: NodeNextRequest, res: NodeNextResponse, pathname: string, query: NextParsedUrlQuery, renderOpts: RenderOpts): Promise<RenderResult | null>;
    protected getPagePath(pathname: string, locales?: string[]): string;
    protected findPageComponents({ pathname, query, params, isAppPath, }: {
        pathname: string;
        query: NextParsedUrlQuery;
        params: Params | null;
        isAppPath: boolean;
    }): Promise<FindComponentsResult | null>;
    protected getFontManifest(): FontManifest;
    protected getServerComponentManifest(): any;
    protected getServerCSSManifest(): any;
    protected getFontLoaderManifest(): any;
    protected getFallback(page: string): Promise<string>;
    protected generateRoutes(): {
        headers: Route[];
        rewrites: {
            beforeFiles: Route[];
            afterFiles: Route[];
            fallback: Route[];
        };
        fsRoutes: Route[];
        redirects: Route[];
        catchAllRoute: Route;
        catchAllMiddleware: Route[];
        pageChecker: PageChecker;
        useFileSystemPublicRoutes: boolean;
        dynamicRoutes: DynamicRoutes | undefined;
        nextConfig: NextConfig;
    };
    /**
     * Resolves `API` request
     * @param req http request
     * @param res http response
     * @param pathname path of request
     * @param query
     */
    protected handleApiRequest(req: BaseNextRequest, res: BaseNextResponse, pathname: string, query: ParsedUrlQuery): Promise<boolean>;
    private _cachedPreviewManifest;
    protected getPrerenderManifest(): PrerenderManifest;
    protected attachRequestMeta(req: BaseNextRequest, parsedUrl: NextUrlWithParsedQuery): void;
    protected get serverDistDir(): string;
}
//# sourceMappingURL=next-compute-js-server.d.ts.map